cmd

package
v0.6.22 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 7, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var RootCmd = &cobra.Command{
	Use:   "tnnl",
	Short: "Use ECS Exec and port forwarding through AWS Systems Manager Session Manager",
	Long: "tnnl selects a ready ECS task and container for exec or port forwarding.\n" +
		"AWS credentials and Region come from the AWS SDK default configuration chain; set\n" +
		"AWS_PROFILE/AWS_REGION or run through tools such as `aws-vault exec NAME -- tnnl ...`.\n" +
		"session-manager-plugin (Session Manager Plugin) must be installed and available on PATH.",
	SilenceErrors: true,
	SilenceUsage:  true,
	RunE: func(cmd *cobra.Command, args []string) error {
		if shortVersion {
			return writeVersion(cmd)
		}

		return cmd.Help()
	},
}

rootCmd represents the base command when called without any subcommands

var Version = buildinfo.Current()

Functions

func ExecuteContext added in v0.6.18

func ExecuteContext(ctx context.Context) error

Types

This section is empty.

Directories

Path Synopsis

Jump to